==> qmmp-1.5.4.tar.bz2: qmmp-1.5.4/src/plugins/General/converter/translations/converter_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="124"/>
        <location filename="../converter.cpp" line="227"/>
        <source>Cancelled</source>
        <translation>Peruttu</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="139"/>
        <location filename="../converter.cpp" line="209"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="177"/>
        <source>Converting</source>
        <translation>Muuntaminen</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="238"/>
        <source>Encoding</source>
        <translation>Koodaus</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="280"/>
        <source>Finished</source>
        <translation>Valmis</translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Audio Converter</source>
        <translation>Äänimuunnin</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="44"/>
        <source>Progress</source>
        <translation>Edistyminen</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="49"/>
        <source>State</source>
        <translation>Tila</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Output directory:</source>
        <translation>Tallennus kansio:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="80"/>
        <source>Output file name:</source>
        <translation>Tallennuksen tiedoston nimi:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="97"/>
        <source>Preset:</source>
        <translation>Esiasetus:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="114"/>
        <source>Overwrite existing files</source>
        <translation>Korvaa tiedostot</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="124"/>
        <source>Convert</source>
        <translation>Muunna</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="131"/>
        <source>Stop</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="113"/>
        <source>Choose a directory</source>
        <translation>Valitse kansio</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="39"/>
        <source>Title</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="203"/>
        <source>Create a Copy</source>
        <translation>Luo kopio</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="134"/>
        <location filename="../converterdialog.cpp" line="358"/>
        <location filename="../converterdialog.cpp" line="364"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="139"/>
        <source>Waiting</source>
        <translation>Odottaa</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="201"/>
        <source>Create</source>
        <translation>Luo</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="202"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="204"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="358"/>
        <source>Unable to execute &quot;%1&quot;. Program not found.</source>
        <translation>&quot;%1&quot; ei voida suorittaa. Ohjelmaa ei löydy.</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="364"/>
        <source>Process &quot;%1&quot; finished with error.</source>
        <translation>Prosessi &quot;%1&quot; valmistui virheellisesti.</translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="28"/>
        <source>Converter Plugin</source>
        <translation>Muuntimen liitännäinen</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="49"/>
        <source>About Converter Plugin</source>
        <translation>Tietoja muuntimen liitännäisestä</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="50"/>
        <source>Qmmp Converter Plugin</source>
        <translation>Qmmp Converter Plugin</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation>Tämä laajennus muuntaa tuetut äänitiedostot muihin tiedostomuotoihin käyttäen komentorivin koodereita</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="33"/>
        <source>Convert</source>
        <translation>Muunna</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="34"/>
        <source>Meta+C</source>
        <translation>Meta+C</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Asetettu editori</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation>Liitännäinen:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation>Komento</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation>Valinnat</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation>Kirjoita hakusana</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation>Muunna 16-bittiseksi</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation>%1 (Vain luku)</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation>Tallennuksen tiedosto</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation>Tuo tiedosto</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/converter/translations/converter_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="124"/>
        <location filename="../converter.cpp" line="227"/>
        <source>Cancelled</source>
        <translation>Peruttu</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="139"/>
        <location filename="../converter.cpp" line="209"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="177"/>
        <source>Converting</source>
        <translation>Muuntaminen</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="238"/>
        <source>Encoding</source>
        <translation>Koodaus</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="280"/>
        <source>Finished</source>
        <translation>Valmis</translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Audio Converter</source>
        <translation>Äänimuunnin</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="44"/>
        <source>Progress</source>
        <translation>Edistyminen</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="49"/>
        <source>State</source>
        <translation>Tila</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Output directory:</source>
        <translation>Tallennus kansio:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="80"/>
        <source>Output file name:</source>
        <translation>Tallennuksen tiedoston nimi:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="97"/>
        <source>Preset:</source>
        <translation>Esiasetus:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="114"/>
        <source>Overwrite existing files</source>
        <translation>Korvaa tiedostot</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="124"/>
        <source>Convert</source>
        <translation>Muunna</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="131"/>
        <source>Stop</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="113"/>
        <source>Choose a directory</source>
        <translation>Valitse kansio</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="39"/>
        <source>Title</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="203"/>
        <source>Create a Copy</source>
        <translation>Luo kopio</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="134"/>
        <location filename="../converterdialog.cpp" line="358"/>
        <location filename="../converterdialog.cpp" line="364"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="139"/>
        <source>Waiting</source>
        <translation>Odottaa</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="201"/>
        <source>Create</source>
        <translation>Luo</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="202"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="204"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="358"/>
        <source>Unable to execute &quot;%1&quot;. Program not found.</source>
        <translation>&quot;%1&quot; ei voida suorittaa. Ohjelmaa ei löydy.</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="364"/>
        <source>Process &quot;%1&quot; finished with error.</source>
        <translation>Prosessi &quot;%1&quot; valmistui virheellisesti.</translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="28"/>
        <source>Converter Plugin</source>
        <translation>Converter Plugin</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="49"/>
        <source>About Converter Plugin</source>
        <translation>Tietoja: Converter Plugin</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="50"/>
        <source>Qmmp Converter Plugin</source>
        <translation>Qmmp Converter Plugin</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation>Tämä laajennus muuntaa tuetut äänitiedostot muihin tiedostomuotoihin käyttäen komentorivin koodereita</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="33"/>
        <source>Convert</source>
        <translation>Muunna</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="34"/>
        <source>Meta+C</source>
        <translation>Meta+C</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Asetettu editori</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation>Laajennus:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation>Komento</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation>Valinnat</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation>Kirjoita hakusanat</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation>Muunna 16-bittiseksi</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation>%1 (vain luku)</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation>Tallennus tiedosto</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation>Tuo tiedosto</translation>
    </message>
</context>
</TS>
